@@ -33,6 +33,10 @@ class SqlAlchemyPool(BaseConnectionPool):
             url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
                 self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
                 self.conn_info.db_name)
+        elif db_type == "dm":
+            url = 'dm+dmPython://{}:{}@{}:{}'.format(
+                self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
+                self.conn_info.db_name)
         else:
             raise Exception("UNSUPPORTED DB TYPE")
         try:
