@@ -16,6 +16,23 @@ from threading import Thread
 
 # 装饰器
 
+def common_cache(func, ex, *args, **params):
+    try:
+        data = deal_cache(func, ex, None, *args, **params)
+    except Exception as e:
+        logging.error(traceback.format_exc())
+        data = func(*args, **params)
+    return data
+
+
+async def async_common_cache(func, ex, *args, **params):
+    try:
+        data = deal_cache(func, ex, None, *args, **params)
+    except Exception as e:
+        logging.error(traceback.format_exc())
+        data = await func(*args, **params)
+    return data
+
 
 def Cache(ex=3600 * 12, cache_key=None):
     def cache_func(func):
@@ -64,6 +81,24 @@ def query_cache(cache_key, params=None, ex=3600 * 12, func=None, args=None, conn
     if options.cache_enable:
         ttl = RedisHelper(conn_name).get_connection(sync=True).ttl(cache_key)
 
+        if ttl and ex >= 900 and 0 < ttl <= ex - 900:
+            Thread(target=request_interface, kwargs={
+                "func": func,
+                "params": params,
+                "args": args,
+                "ex": ex,
+                "cache_key": cache_key
+            }).start()
+        data = RedisHelper(conn_name).sync_get(cache_key)
+        if data:
+            value = json.loads(data)
+            return value
+        else:
+            logging.info("str_select_key为".format(cache_key))
+            return False
+    if options.common_cache_enable:
+        ttl = RedisHelper(conn_name).get_connection(sync=True).ttl(cache_key)
+
         if ttl and ex >= 900 and 0 < ttl <= ex - 900:
             Thread(target=request_interface, kwargs={
                 "func": func,
@@ -117,3 +152,8 @@ def insert_cache(data, ex, cache_key, conn_name=None):
                 RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
             except:
                 logging.error(traceback.format_exc())
+        if options.common_cache_enable:
+            try:
+                RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
+            except:
+                logging.error(traceback.format_exc())
