@@ -20,6 +20,7 @@ from tornado.options import options
 from tornado.web import RequestHandler, Application
 
 from lesscode.task.task_helper import TaskHelper
+from lesscode.utils.CacheUtil import async_common_cache, common_cache
 from lesscode.utils.es_log.record_log import es_record_log
 from lesscode.utils.json import JSONEncoder
 from lesscode.web.business_exception import BusinessException
@@ -257,11 +258,18 @@ class BaseHandler(RequestHandler):
             try:
                 if inspect.iscoroutinefunction(handler_method):
                     # data = await handler_method(*params_list)
-                    data = await handler_method(**params_dict)
+                    if options.common_cache_enable:
+                        data = await async_common_cache(handler_method, options.common_cache_ex, **params_dict)
+                    else:
+                        data = await handler_method(**params_dict)
+
                 else:
                     # 阻塞方法异步调用
                     # data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-                    func = lambda: handler_method(**params_dict)
+                    if options.common_cache_enable:
+                        func = lambda: common_cache(handler_method, options.common_cache_ex, **params_dict)
+                    else:
+                        func = lambda: handler_method(**params_dict)
                     data = await IOLoop.current().run_in_executor(None, func)
                 self.end_time = int(round(time.time() * 1000))
                 self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
