@@ -219,6 +219,18 @@ class StatusCode:
     # B04开头的状态码
     RESOURCE_NOT_FOUND = ("B0404", "访问资源不存在")
 
+    @staticmethod
+    def RESOURCE_NOT_EXIST(resource):
+        return "B0405", f"访问资源({resource})不存在"
+
+    @staticmethod
+    def BOUNDED(info):
+        return "B0406", f"三方账号({info})已绑定其他账号"
+
+    @staticmethod
+    def UNBOUNDED(info):
+        return "B0407", f"三方账号({info})还没有绑定"
+
     # B05开头的状态码
     @staticmethod
     def INTERNAL_SERVER_ERROR(message):
