@@ -53,6 +53,8 @@ define("kafka_config", default={}, type=dict, help="kafka配置")
 define("log_es_config", default={}, type=dict, help="同步日志到es的配置")
 define("cache_conn", default="redis_con_1", type=str, help="redis缓存连接")
 define("cache_enable", default=False, type=bool, help="redis缓存开关")
+define("common_cache_enable", default=False, type=bool, help="redis缓存开关")
+define("common_cache_ex", default=3600 * 12, type=int, help="redis缓存时间，单位秒")
 define("task_list", default=[], type=list, help="任务列表")
 define("correction_param", default={"enable": False}, type=dict, help="aes加密key")
 define("sentry_config", default={"enable": False}, type=dict, help="sentry配置")
